Welcome to svg.charts documentation!
====================================

.. toctree::
   :maxdepth: 2
   :glob:

   *

   history


.. automodule:: svg.charts
    :members:
    :undoc-members:
    :show-inheritance:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

